package com.netmera.netmera_flutter_sdk;

import android.content.Context;

import com.netmera.NetmeraConfiguration;
import com.netmera.callbacks.NMInAppMessageActionCallbacks;
import com.netmera.callbacks.NMPushActionCallbacks;

public class FNetmeraConfiguration {

    NMInAppMessageActionCallbacks nmInAppMessageActionCallbacks;
    NMPushActionCallbacks nmPushActionCallbacks;
    Context context;
    String baseUrl;
    String huaweiSenderId;
    String apiKey;
    String firebaseSenderId;
    boolean logging;

    private FNetmeraConfiguration(Builder builder) {
        this.nmInAppMessageActionCallbacks = builder.nmInAppMessageActionCallbacks;
        this.nmPushActionCallbacks = builder.nmPushActionCallbacks;
        this.context = builder.context;
        this.baseUrl = builder.baseUrl;
        this.huaweiSenderId = builder.huaweiSenderId;
        this.apiKey = builder.apiKey;
        this.firebaseSenderId = builder.firebaseSenderId;
        this.logging = builder.logging;
    }

    NetmeraConfiguration getNetmeraConfiguration() {
        NMPushActionCallbacks nmPushActionCallbacks =
                this.nmPushActionCallbacks != null ?
                        this.nmPushActionCallbacks :
                        new FNetmeraPushBroadcastReceiver();

        NetmeraConfiguration.Builder builder = new NetmeraConfiguration.Builder();

        if (firebaseSenderId != null) {
            builder.firebaseSenderId(firebaseSenderId);
        }

        if (huaweiSenderId != null) {
            builder.huaweiSenderId(huaweiSenderId);
        }

        if (apiKey != null) {
            builder.apiKey(apiKey);
        }

        if (baseUrl != null) {
            builder.baseUrl(baseUrl);
        }

        if (nmInAppMessageActionCallbacks != null) {
            builder.nmInAppMessageActionCallbacks(nmInAppMessageActionCallbacks);
        }

        return builder.logging(logging)
                .disableSerializeRule(true)
                .nmPushActionCallbacks(nmPushActionCallbacks)
                .build(context);
    }

    public static class Builder {
        private NMInAppMessageActionCallbacks nmInAppMessageActionCallbacks;
        private NMPushActionCallbacks nmPushActionCallbacks;
        private Context context;
        private String baseUrl;
        private String huaweiSenderId;
        private String apiKey;
        private String firebaseSenderId;
        private boolean logging;

        public Builder nmInAppMessageActionCallbacks(NMInAppMessageActionCallbacks nmInAppMessageActionCallbacks) {
            this.nmInAppMessageActionCallbacks = nmInAppMessageActionCallbacks;
            return this;
        }

        public Builder nmPushActionCallbacks(NMPushActionCallbacks nmPushActionCallbacks) {
            this.nmPushActionCallbacks = nmPushActionCallbacks;
            return this;
        }

        public Builder baseUrl(String baseUrl) {
            this.baseUrl = baseUrl;
            return this;
        }

        public Builder huaweiSenderId(String huaweiSenderId) {
            this.huaweiSenderId = huaweiSenderId;
            return this;
        }

        public Builder apiKey(String apiKey) {
            this.apiKey = apiKey;
            return this;
        }

        public Builder firebaseSenderId(String firebaseSenderId) {
            this.firebaseSenderId = firebaseSenderId;
            return this;
        }

        public Builder logging(boolean logging) {
            this.logging = logging;
            return this;
        }

        public FNetmeraConfiguration build(Context context) {
            this.context = context;
            return new FNetmeraConfiguration(this);
        }
    }
}
