/**
 * Copyright (c) 2019 Inomera Research.
 * @author Burak Soykal
 */

#import "FNetmeraPushObject.h"

@implementation FNetmeraPushObject


+(NSArray<NSDictionary*>*) mapPushObjects: (NSMutableArray<NetmeraPushObject *>*) pushObjects {
    NSMutableArray<NSDictionary*> *pushObjectList = [[NSMutableArray alloc]init];
    for (int i = 0; i < [pushObjects count]; i++) {
        [pushObjectList addObject: [self getPushObjectMap: pushObjects[i]]];
    }
    return pushObjectList;
}

+(NSDictionary*) getPushObjectMap:(NetmeraPushObject*) pushObject {
    NSMutableDictionary *data = [NSMutableDictionary dictionary];
    data[@"pushType"] = [NSNumber numberWithInteger:[pushObject pushType]];
    data[@"pushId"] = [pushObject pushId];
    data[@"pushInstanceId"] = [pushObject pushInstanceId];
    data[@"inboxStatus"] = [NSNumber numberWithInteger:[pushObject inboxStatus]];
    data[@"category"] = [pushObject interactiveCategoryIdentifier];
    data[@"customJson"] = [pushObject customDictionary];
    data[@"action_deeplink_url"] = [pushObject action].deeplinkURLString;
    data[@"action_webpage_url"] = [[[pushObject dictionaryValue] objectForKey:@"_nm.act"] objectForKey:@"url"];
    data[@"externalId"] = [pushObject externalId];
    data[@"title"] = [[pushObject alert] title];
    data[@"subtitle"] = [[pushObject alert] subtitle];
    data[@"body"] = [[pushObject alert] body];
    data[@"mediaAttachmentURL"] = [[pushObject mediaAttachmentURL] absoluteString];
    data[@"categories"] = [pushObject category];
    data[@"carousel"] = [pushObject carousel];
   
    if(pushObject.expirationDate!=nil){
        NSDateFormatter *dateFormatter = [[NSDateFormatter alloc] init];
        [dateFormatter setDateFormat:@"yyyy-MM-dd HH:mm:ss"];
        data[@"expireTime"] = [dateFormatter stringFromDate:pushObject.expirationDate];
    }
    
    
    if(pushObject.interactiveActions != nil) {
        NSMutableArray *actions = [[NSMutableArray alloc]init];
        for(int i = 0 ; i < [pushObject.interactiveActions count]; i++) {
            NSMutableDictionary *action = [NSMutableDictionary dictionary];
            action[@"id"] = pushObject.interactiveActions[i].interactiveAction.identifier;
            action[@"text"] = pushObject.interactiveActions[i].interactiveAction.title;
            action[@"act"] = pushObject.interactiveActions[i].actionDictionary;
            action[@"prms"] = pushObject.interactiveActions[i].customDictionary;
            [actions addObject:action];
        }
        NSError *error;
        NSData *dataxx = [NSJSONSerialization dataWithJSONObject:actions options:0 error:&error];
        NSString *jsonStr = [[NSString alloc] initWithData:dataxx encoding:NSUTF8StringEncoding];
        [data setValue:jsonStr forKey:@"interactiveActions"];
    }

    if(pushObject.sendDate){
        NSDateFormatter *dateFormatter = [[NSDateFormatter alloc] init];
        [dateFormatter setDateFormat:@"yyyy-MM-dd HH:mm:ss"];
        data[@"sendDate"] = [dateFormatter stringFromDate:pushObject.sendDate];
    }
    
    if([[pushObject dictionaryValue] objectForKey:@"_nm.act"] != nil){
         data[@"pushAction"] = [[pushObject dictionaryValue] objectForKey:@"_nm.act"];
    }
    return data;
}


@end
