import 'dart:async';
import 'dart:collection';
import 'dart:ui';

import 'package:flutter/services.dart';
import 'package:flutter/widgets.dart';

import 'callbackDispatcher.dart';

typedef void MessageHandler(Map<dynamic, dynamic> bundle);

class NetmeraPushBroadcastReceiver {
  factory NetmeraPushBroadcastReceiver() => _instance;

  NetmeraPushBroadcastReceiver.private(MethodChannel channel) : _channel = channel;

  static final NetmeraPushBroadcastReceiver _instance =
      NetmeraPushBroadcastReceiver.private(const MethodChannel('netmera_flutter_sdk'));

  final MethodChannel _channel;

  Future<void> initialize(
      {MessageHandler? onPushRegister,
      MessageHandler? onPushReceive,
      MessageHandler? onPushDismiss,
      MessageHandler? onPushOpen,
      MessageHandler? onPushButtonClicked,
      MessageHandler? onCarouselObjectSelected}) async {
    WidgetsFlutterBinding.ensureInitialized();
    HashMap<String, dynamic> list = HashMap();

    if (callbackDispatcher != null)
      list["callback_dispatch_handler"] = PluginUtilities.getCallbackHandle(callbackDispatcher)!.toRawHandle();
    if (onPushRegister != null) list["onPushRegister"] = PluginUtilities.getCallbackHandle(onPushRegister)!.toRawHandle();
    if (onPushReceive != null) list["onPushReceive"] = PluginUtilities.getCallbackHandle(onPushReceive)!.toRawHandle();
    if (onPushDismiss != null) list["onPushDismiss"] = PluginUtilities.getCallbackHandle(onPushDismiss)!.toRawHandle();
    if (onPushOpen != null) list["onPushOpen"] = PluginUtilities.getCallbackHandle(onPushOpen)!.toRawHandle();
    if (onPushButtonClicked != null)
      list["onPushButtonClicked"] = PluginUtilities.getCallbackHandle(onPushButtonClicked)!.toRawHandle();
    if (onCarouselObjectSelected != null)
      list["onCarouselObjectSelected"] = PluginUtilities.getCallbackHandle(onCarouselObjectSelected)!.toRawHandle();

    await _channel.invokeMethod('initService', list);
  }
}
